require File.dirname(__FILE__) + '/../test_helper'

class DiagramCacheDatumTest < ActiveSupport::TestCase
  fixtures :diagram_cache_data

  # Replace this with your real tests.
  def test_truth
    assert true
  end
end
